<?php

/**
* The dashboard-specific functionality of the plugin.
*
* @link 		https://lin3s.com
* @since 		1.0.0
*
* @package 		Alexandria_Mail_Builder
* @subpackage 	Alexandria_Mail_Builder/admin
*/

class Alexandria_Mail_Builder_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since 		1.0.0
	 * @access 		private
	 * @var 		string 			$plugin_name 		The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since 		1.0.0
	 * @access 		private
	 * @var 		string 			$version 			The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since 		1.0.0
	 * @param 		string 			$plugin_name 			The name of this plugin.
	 * @param 		string 			$version 				The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

		define( 'ALEXANDRIA_MAIL_BUILDER_ADMIN_PATH', plugin_dir_url( __FILE__ ));

	}

	/**
     * Adds notices for the admin to display.
     * Saves them in a temporary plugin option.
     * This method is called on plugin activation, so its needs to be static.
     */
	public static function add_admin_notices() {

		$notices = get_option( 'alexandria_mail_builder_deferred_admin_notices', array() );

		apply_filters( 'alexandria_mail_builder_admin_notices', $notices );
		update_option( 'alexandria_mail_builder_deferred_admin_notices', $notices );

    } // add_admin_notices

	/**
	 * Adds a settings page link to a menu
	 *
	 * @link 		https://codex.wordpress.org/Administration_Menus
	 * @since 		1.0.0
	 * @return 		void
	 */
	public function add_menu() {

		$alexandria_mail_caps = current_user_can('manage_options') ? 'manage_options' : 'alexandria_mail_manage';

		// Top-level page
		// add_menu_page( $page_title, $menu_title, $capability, $menu_slug, $function, $icon_url, $position );

		// Submenu Page
		// add_submenu_page( $parent_slug, $page_title, $menu_title, $capability, $menu_slug, $function);

		add_menu_page(
			esc_html__('Buider de E-Mail', 'alexandria-mail-builder'),
			esc_html__('Buider de E-Mail', 'alexandria-mail-builder'),
			$alexandria_mail_caps,
			$this->plugin_name . '-admin-menu',
			array( $this, 'page_landing' ),
			'dashicons-email-alt'
		);

		add_submenu_page(
			$this->plugin_name . '-admin-menu',
			apply_filters( $this->plugin_name . '-mails-list-page-title', esc_html__( 'E-Mails', 'alexandria-mail-builder' ) ),
			apply_filters( $this->plugin_name . '-mails-list-menu-title', esc_html__( 'E-Mails', 'alexandria-mail-builder' ) ),
			$alexandria_mail_caps,
			'/edit.php?post_type=emails'
		);

		add_submenu_page(
			$this->plugin_name . '-admin-menu',
			apply_filters( $this->plugin_name . '-interlocutores-list-page-title', esc_html__( 'Interlocutores', 'alexandria-mail-builder' ) ),
			apply_filters( $this->plugin_name . '-interlocutores-list-menu-title', esc_html__( 'Interlocutores', 'alexandria-mail-builder' ) ),
			$alexandria_mail_caps,
			'/edit.php?post_type=interlocutors_email'
		);

		add_submenu_page(
			$this->plugin_name . '-admin-menu',
			apply_filters( 'alexandria-mail-builder' . '-situations-list-page-title', esc_html__( 'Situaciones', 'alexandria-mail-builder' ) ),
			apply_filters( $this->plugin_name . '-situations-list-menu-title', esc_html__( 'Situaciones', 'alexandria-mail-builder' ) ),
			$alexandria_mail_caps,
			'/edit.php?post_type=situations_email'
		);

		add_submenu_page(
			$this->plugin_name . '-admin-menu',
			apply_filters( 'alexandria-mail-builder' . '-situations-list-page-title', esc_html__( 'Tipos de Situaciones', 'alexandria-mail-builder' )),
			apply_filters( 'alexandria-mail-builder' . '-situations-list-menu-title', esc_html__( 'Tipos de Situaciones', 'alexandria-mail-builder' )),
			$alexandria_mail_caps,
			'/edit-tags.php?taxonomy=situations-email-categories'
		);

		add_submenu_page(
			$this->plugin_name . '-admin-menu',
			apply_filters( 'alexandria-mail-builder' . '-tonos-list-page-title', esc_html__( 'Tonos', 'alexandria-mail-builder' ) ),
			apply_filters( 'alexandria-mail-builder' . '-tonos-list-menu-title', esc_html__( 'Tonos', 'alexandria-mail-builder' ) ),
			$alexandria_mail_caps,
			'/edit.php?post_type=tonos_email'
		);

		add_menu_page(
			esc_html__('Builder de E-Mail - Output', 'alexandria-mail-builder'),
			esc_html__('Builder de E-Mail - Output', 'alexandria-mail-builder'),
			$alexandria_mail_caps,
			$this->plugin_name . '-second-menu',
			array( $this, 'page_landing_elements' ),
			'dashicons-buddicons-pm'
		);

		add_submenu_page(
			$this->plugin_name . '-second-menu',
			apply_filters( $this->plugin_name . '-gran-idea-email-list-page-title', esc_html__( 'Listado de Grandes Ideas - Email', 'alexandria-mail-builder' )),
			apply_filters( $this->plugin_name . '-gran-idea-email-list-menu-title', esc_html__( 'Gran Idea - Email', 'alexandria-mail-builder' )),
			$alexandria_mail_caps,
			'/edit.php?post_type=gran_ideas_email'
		);

		add_submenu_page(
			$this->plugin_name . '-second-menu',
			apply_filters( $this->plugin_name . '-arguments-email-list-page-title', esc_html__( 'Listado de Argumentos - Email', 'alexandria-mail-builder' )),
			apply_filters( $this->plugin_name . '-arguments-email-list-menu-title', esc_html__( 'Argumentos - Email', 'alexandria-mail-builder' )),
			$alexandria_mail_caps,
			'/edit.php?post_type=arguments_email'
		);

		add_submenu_page(
			$this->plugin_name . '-second-menu',
			apply_filters( $this->plugin_name . '-content-boxes-list-page-title', esc_html__( 'Listado de Cajas de Contenido', 'alexandria-mail-builder' )),
			apply_filters( $this->plugin_name . '-content-boxes-list-menu-title', esc_html__( 'Cajas de Contenido', 'alexandria-mail-builder' )),
			$alexandria_mail_caps,
			'/edit.php?post_type=content_boxes'
		);

		add_submenu_page(
			$this->plugin_name . '-second-menu',
			apply_filters( $this->plugin_name . '-engagement-boxes-list-page-title', esc_html__( 'Listado de Cajas de Engagement', 'alexandria-mail-builder' )),
			apply_filters( $this->plugin_name . '-engagement-boxes-list-menu-title', esc_html__( 'Cajas de Engagement', 'alexandria-mail-builder' )),
			$alexandria_mail_caps,
			'/edit.php?post_type=engagement_boxes'
		);

		add_submenu_page(
			$this->plugin_name . '-second-menu',
			apply_filters( $this->plugin_name . '-ingredients-list-page-title', esc_html__( 'Listado de Ingredientes', 'alexandria-mail-builder' )),
			apply_filters( $this->plugin_name . '-ingredients-list-menu-title', esc_html__( 'Ingredientes', 'alexandria-mail-builder' )),
			$alexandria_mail_caps,
			'/edit.php?post_type=ingredients'
		);

		add_submenu_page(
			$this->plugin_name . '-second-menu',
			apply_filters( $this->plugin_name . '-soliloquios-email-list-page-title', esc_html__( 'Listado de Soliloquios', 'alexandria-mail-builder' ) ),
			apply_filters( $this->plugin_name . '-soliloquios-email-list-menu-title', esc_html__( 'Soliloquios', 'alexandria-mail-builder' ) ),
			$alexandria_mail_caps,
			'/edit.php?post_type=soliloquios_email'
		);

		add_submenu_page(
			$this->plugin_name . '-second-menu',
			apply_filters( $this->plugin_name . '-gran-idea-pitch-list-page-title', esc_html__( 'Listado de Grandes Ideas - Pitch', 'alexandria-mail-builder' ) ),
			apply_filters( $this->plugin_name . '-gran-idea-pitch-list-menu-title', esc_html__( 'Grandes Ideas - Pitch', 'alexandria-mail-builder' ) ),
			$alexandria_mail_caps,
			'/edit.php?post_type=gran_ideas_pitch'
		);

		add_submenu_page(
			$this->plugin_name . '-second-menu',
			apply_filters( $this->plugin_name . '-arguments-pitch-list-page-title', esc_html__( 'Listado de Argumentos - Pitch', 'alexandria-mail-builder' ) ),
			apply_filters( $this->plugin_name . '-arguments-pitch-list-menu-title', esc_html__( 'Argumentos - Pitch', 'alexandria-mail-builder' ) ),
			$alexandria_mail_caps,
			'/edit.php?post_type=arguments_pitch'
		);

		add_submenu_page(
			$this->plugin_name . '-second-menu',
			apply_filters( $this->plugin_name . '-call-to-action-list-page-title', esc_html__( 'Listado de Llamadas a la Acción', 'alexandria-mail-builder' ) ),
			apply_filters( $this->plugin_name . '-call-to-action-list-menu-title', esc_html__( 'Llamadas a la Acción', 'alexandria-mail-builder' ) ),
			$alexandria_mail_caps,
			'/edit.php?post_type=call_to_action_email'
		);

		add_submenu_page(
			$this->plugin_name . '-second-menu',
			apply_filters( $this->plugin_name . '-alexandria-examples-list-page-title', esc_html__( 'Listado de Ejemplos', 'alexandria-mail-builder' ) ),
			apply_filters( $this->plugin_name . '-alexandria-examples-list-menu-title', esc_html__( 'Ejemplos', 'alexandria-mail-builder' ) ),
			$alexandria_mail_caps,
			'/edit.php?post_type=examples_email'
		);

		add_submenu_page(
			$this->plugin_name . '-second-menu',
			apply_filters( $this->plugin_name . '-alexandria-comments-list-page-title', esc_html__( 'Listado de Comentarios', 'alexandria-mail-builder' ) ),
			apply_filters( $this->plugin_name . '-alexandria-comments-list-menu-title', esc_html__( 'Comentarios', 'alexandria-mail-builder' ) ),
			$alexandria_mail_caps,
			'/edit.php?post_type=comments_email'
		);

		add_menu_page(
			esc_html__('Builder de E-Mail - Configuración', 'alexandria-mail-builder'),
			esc_html__('Builder de E-Mail - Configuración', 'alexandria-mail-builder'),
			$alexandria_mail_caps,
			$this->plugin_name . '-config-menu',
			array( $this, 'page_options' ),
			'dashicons-admin-generic'
		);

		// add_submenu_page(
		// 	$this->plugin_name . '-config-menu',
		// 	apply_filters( $this->plugin_name . '-export-page-title', esc_html__( 'Exportador', $this->plugin_name ) ),
		// 	apply_filters( $this->plugin_name . '-export-menu-title', esc_html__( 'Exportador', $this->plugin_name ) ),
		// 	$alexandria_mail_caps,
		// 	$this->plugin_name . '-export',
		// 	array( $this, 'page_export' )
		// );

		add_submenu_page(
			$this->plugin_name . '-config-menu',
			apply_filters( $this->plugin_name . '-settings-page-title', esc_html__( 'Configuración', 'alexandria-mail-builder' ) ),
			apply_filters( $this->plugin_name . '-settings-menu-title', esc_html__( 'Configuración', 'alexandria-mail-builder' ) ),
			$alexandria_mail_caps,
			$this->plugin_name . '-settings',
			array( $this, 'page_options' )
		);

		add_submenu_page(
			$this->plugin_name . '-config-menu',
			apply_filters( $this->plugin_name . '-objectives-page-title', esc_html__( 'Objetivos Página Principal', 'alexandria-mail-builder' ) ),
			apply_filters( $this->plugin_name . '-objectives-menu-title', esc_html__( 'Objetivos Página Principal', 'alexandria-mail-builder' ) ),
			$alexandria_mail_caps,
			'/edit.php?post_type=objectives_email'
		);

		add_submenu_page(
			$this->plugin_name . '-config-menu',
			apply_filters( $this->plugin_name . '-help-page-title', esc_html__( 'Ayuda', 'alexandria-mail-builder' ) ),
			apply_filters( $this->plugin_name . '-help-menu-title', esc_html__( 'Ayuda', 'alexandria-mail-builder' ) ),
			$alexandria_mail_caps,
			$this->plugin_name . '-help',
			array( $this, 'page_help' )
		);

	} // add_menu()

	/**
     * Manages any updates or upgrades needed before displaying notices.
     * Checks plugin version against version required for displaying
     * notices.
     */
	public function admin_notices_init() {

		$current_version = '1.0.0';

		if ( $this->version !== $current_version ) {

			// Do whatever upgrades needed here.

			update_option('1.0.0', $current_version);

			$this->add_notice();
		}

	} // admin_notices_init()

	/**
     * Manages any updates or upgrades needed before displaying notices.
     * Checks plugin version against version required for displaying
     * notices.
     */
	public function db_init() {

		add_action('init', array("AlexandriaMailBuilder", "init"));

	} // db_init()

	function menu_highlight( $parent_file ) {
        global $current_screen;

        $taxonomy = $current_screen->taxonomy;

        if ( $taxonomy == 'situations-emails-categories' ) {
            $parent_file = 'situations';
        }

        return $parent_file;
    }


	/**
	 * Displays admin notices
	 *
	 * @return 	string 			Admin notices
	 */
	public function display_admin_notices() {

		$notices = get_option( 'alexandria_mail_builder_deferred_admin_notices' );

		if ( empty( $notices ) ) { return; }

		foreach ( $notices as $notice ) {

			echo '<div class="' . esc_attr( $notice['class'] ) . '"><p>' . $notice['notice'] . '</p></div>';

		}

		delete_option( 'alexandria_mail_builder_deferred_admin_notices' );

    } // display_admin_notices()

	/**
	 * Register the stylesheets for the Dashboard.
	 *
	 * @since 		1.0.0
	 */
	public function enqueue_styles() {
		wp_enqueue_style( 'wp-color-picker' );
		wp_register_style( 'select2css', '//cdnjs.cloudflare.com/ajax/libs/select2/3.4.8/select2.css', false, '1.0', 'all' );
		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/' . $this->plugin_name . '-admin.css', array(), $this->version, 'all' );

		wp_enqueue_style( 'select2css' );
		

	} // enqueue_styles()

	/**
	 * Register the JavaScript for the dashboard.
	 *
	 * @since 		1.0.0
	 */
	public function enqueue_scripts( $hook_suffix ) {
		wp_enqueue_script('jquery');
		wp_enqueue_script('jquery-ui-sortable');

		wp_register_script( 'select2', '//cdnjs.cloudflare.com/ajax/libs/select2/3.4.8/select2.js', array( 'jquery' ), '1.0', true );	
		wp_register_script( $this->plugin_name.'-dual-box', plugin_dir_url( __FILE__ ) . 'js/' . $this->plugin_name . '-dual-box.js', '1.0', true);
		wp_register_script( $this->plugin_name.'-order-list', plugin_dir_url( __FILE__ ) . 'js/' . $this->plugin_name . '-order-list.js', array('jquery'), '1.0', true);
		wp_register_script( $this->plugin_name.'-video-uploader', plugin_dir_url( __FILE__ ) . 'js/' . $this->plugin_name . '-video-uploader.js', array('jquery'), '1.0', true);
		wp_register_script( $this->plugin_name.'-main', plugin_dir_url( __FILE__ ) . 'js/' . $this->plugin_name . '-main.js', array('wp-color-picker', 'jquery'), '1.0', true);

		$translated_form_strings = array(
			'admin_url' => admin_url('admin-ajax.php'),

			'gran_ideas_string' => __('Gran Ideas', 'alexandria-mail-builder'),
			'arguments_string' => __('Argumentos', 'alexandria-mail-builder'),
			'content_boxes_string' => __('Cajas de Contenidos', 'alexandria-mail-builder'),
			'engagement_boxes_string' => __('Cajas de Engagement', 'alexandria-mail-builder'),
			'ingredients_string' => __('Ingredientes', 'alexandria-mail-builder'),
			'soliloquios_string' => __('Soliloquios', 'alexandria-mail-builder'),
			'call_to_action_string' => __('Llamadas a la Acción', 'alexandria-mail-builder'),
			'examples_string' => __('Ejemplos', 'alexandria-mail-builder'),
			'comments_string' => __('Comentarios', 'alexandria-mail-builder'),

			'seleccionadas_string' => __('Seleccionadas', 'alexandria-mail-builder'),
			'seleccionados_string' => __('Seleccionados', 'alexandria-mail-builder'),
			'email_string' => __('E-mail', 'alexandria-mail-builder'),
			'pitch_string' => __('Pitch', 'alexandria-mail-builder'),
			'search_string' => __('Buscar', 'alexandria-mail-builder'),

			'order_string' => __('Ordenar', 'alexandria-mail-builder'),
			'ordering_string' => __('Ordenando', 'alexandria-mail-builder'),
			'order_notice_string' => __('Estas ordenando el listado.', 'alexandria-mail-builder')
		);

		wp_localize_script( $this->plugin_name.'-order-list', 'translated_strings', $translated_form_strings );
		wp_localize_script( $this->plugin_name.'-main', 'translated_strings', $translated_form_strings );

		wp_enqueue_script( 'select2' );
		wp_enqueue_script( $this->plugin_name.'-dual-box' );
		wp_enqueue_script( $this->plugin_name.'-order-list' );
		wp_enqueue_script( $this->plugin_name.'-video-uploader' );
		wp_enqueue_script( $this->plugin_name.'-main' );

	} // enqueue_scripts()
	

	/**
	 * Register Media
	 *
	 * @since 		1.0.0
	 */
	public function load_media_files() {
		wp_enqueue_media();
	} // enqueue_scripts()	add_action( 'admin_enqueue_scripts', 'load_media_files' );


	/**
	 * Adds links to the plugin links row
	 *
	 * @since 		1.0.0
	 * @param 		array 		$links 		The current array of row links
	 * @param 		string 		$file 		The name of the file
	 * @return 		array 					The modified array of row links
	 */
	public function link_row( $links, $file ) {

		if ( ALEXANDRIA_MAIL_BUILDER_FILE === $file ) {
			$links[] = '<a href="https://lin3s.com">LIN3S Web</a>';
		}

		return $links;

	} // link_row()

	/**
	 * Adds a link to the plugin settings page
	 *
	 * @since 		1.0.0
	 * @param 		array 		$links 		The current array of links
	 * @return 		array 					The modified array of links
	 */
	public function link_settings( $links ) {

		$links[] = sprintf( '<a href="%s">%s</a>', esc_url( admin_url( 'admin.php?page=' . $this->plugin_name . '-settings' ) ), esc_html__( 'Configuración', 'alexandria-mail-builder' ) );

		return $links;

	} // link_settings()

	/**
	 * Creates the landing page
	 *
	 * @since 		1.0.0
	 * @return 		void
	 */
	public function page_landing() {

		include( plugin_dir_path( __FILE__ ) . 'partials/' . $this->plugin_name . '-admin-landing.php' );

	} // page_landing()

	/**
	 * Creates the landing page elements
	 *
	 * @since 		1.0.0
	 * @return 		void
	 */
	public function page_landing_elements() {

		include( plugin_dir_path( __FILE__ ) . 'partials/' . $this->plugin_name . '-admin-landing-elements.php' );

	} // page_landing_elements()

	/**
	 * Creates the export page
	 *
	 * @since 		1.0.0
	 * @return 		void
	 */
	public function page_export() {

		include( plugin_dir_path( __FILE__ ) . 'partials/' . $this->plugin_name . '-admin-exporter.php' );

	} // page_landing()

	/**
	 * Creates the options page
	 *
	 * @since 		1.0.0
	 * @return 		void
	 */
	public function page_options() {

		include( plugin_dir_path( __FILE__ ) . 'partials/' . $this->plugin_name . '-admin-page-settings.php' );

	} // page_options()

	/**
	 * Creates the help page
	 *
	 * @since 		1.0.0
	 * @return 		void
	 */
	public function page_help() {

		include( plugin_dir_path( __FILE__ ) . 'partials/' . $this->plugin_name . '-admin-page-help.php' );

	} // page_help()

	/**
	 * Download excel template
	 *
	 * @since 		1.0.0
	 * @return 		file
	 */
	public function alexandria_download_template_ajax() {

		// Downlaod excel template file
		$file_url = 'https://example.com/myfile.ext';
		$tmp_file = download_url( $file_url );
		
	}

	/**
	 * Disable Gutengber in certain post types
	 *
	 * @since 		1.0.0
	 * @return 		file
	 */
	public function alexandria_disable_gutenberg( $is_enabled, $post_type ) {
		if ($post_type === 'objectives_email') return false;
		if ($post_type === 'examples_email') return false;
		return $is_enabled;
	}

	/**
	 * Registers settings fields with WordPress
	 */
	public function register_fields() {

		$plugin_settings = new Alexandria_Mail_Builder_Settings_Fields( $this->plugin_name, $this->version );

		$plugin_settings->register_settings_sections();
		$plugin_settings->register_settings_fields();

	} // register_fields()

	

	/**
	* Registers plugin settings
	*
	* @since 		1.0.0
	* @return 		void
	*/
	public function register_settings() {

		$plugin_settings = new Alexandria_Mail_Builder_Settings_Fields( $this->plugin_name, $this->version );
		
		$plugin_settings->register_settings();

	}// register_settings()

	/**
	 * Returns an array of options names, fields types, and default values
	 *
	 * @return 		array 			An array of options
	 */
	public static function get_options_list() {

		$options = array();
		$options[] = array( 'howtoapply', 'editor', '' );
		$options[] = array( 'alexandria-mail-builder', 'text', '' );

		return $options;

	} // get_options_list()


} // class