<?php

/**
* Principal Controller
*
* @link 		https://lin3s.com
* @since 		1.0.0
*
* @package 		Alexandria_Mail_Builder
* @subpackage 	Alexandria_Mail_Builder/admin/controllers
*/

if( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class MainEmailBuilderController {

	static function intiBuilder() {

		$data = [
			'interlocutors' => [],
			'situations_categories' => [],
			'tonos' => []
		];

		$args = array(  
			'post_type' => 'interlocutors_email',
			'post_status' => 'publish',
			'posts_per_page' => -1,
			'suppress_filters' => 0,
			'orderby' => 'title', 
			'order' => 'ASC'
		);

		$data['interlocutors'] = get_posts($args);

		$cat_args = array(
			'post_type' 	=> 'situations_email',
			'post_status' 	=> 'publish',
			'taxonomy'     	=> 'situations-email-categories',
			'orderby'       => 'id',
			'order'         => 'ASC',
			'field'        	=> 'slug',
			'suppress_filters' => 0,
			'include_children' => false
		);

		$categories = get_categories($cat_args);

		if(!empty($categories)) {

			foreach ( $categories as $key => $category ) {

				$data['situations_categories'][$key]['category'] = $category;

				$situations_args = [
					'post_type' => 'situations_email',
					'orderby'   => 'title',
					'order'     => 'ASC',
					'suppress_filters' => 0,
					'tax_query' => [
						[
							'taxonomy' => 'situations-email-categories',
							'terms' => $category->term_id,
							'include_children' => false
						],
					],

				];

				$situations = get_posts($situations_args);

				foreach ( $situations as $index => $situation ) {

					$data['situations_categories'][$key]['situations'][$index] = $situation;

				}

			}
		}

		$args = array(  
			'post_type' => 'tonos_email',
			'post_status' => 'publish',
			'posts_per_page' => -1,
			'suppress_filters' => 0,
			'orderby' => 'order', 
			'order' => 'ASC'
		);

		$data['tonos'] = get_posts($args);

		echo '|ALEXANDRIAMAILBUILDER|';

		do_action('alexandria_mail_show_main_template', 'main_template_email', $data);

	} // end index


	static function getMailMetadata() {

		$interlocutor_id = $_POST['interlocutor'];
		$situation_id = $_POST['situation'];
		$tono_id = $_POST['tono'];

		$data = [];

		$args = array(  
			'post_type' => 'emails',
			'post_status' => 'publish',
			'posts_per_page' => -1,
			'suppress_filters' => 0,
			'orderby' => 'title', 
			'order' => 'ASC'
		);

		$emails = get_posts($args);

		foreach ($emails as $key => $email) {

			$metadata_array = array(
				
				'interlocutor' => get_post(get_post_meta( $email->ID, '_interlocutor_email', true )),
				'tono' => get_post(get_post_meta( $email->ID, '_tono_email', true )),
				'situation' => get_post(get_post_meta( $email->ID, '_situation_email', true )),

				'soliloquios' => [],
				'gran_ideas_email' => [],
				'arguments_email' => [],
				'call_to_action' => [],
				
				'gran_ideas_pitch' => [],
				'arguments_pitch' => [],
				'content_boxes' => [],
				'engagement_boxes' => [],
				'ingredients' => [],

				'examples_email' => []
			);

			
			$gran_ideas_email = get_post_meta( $email->ID, '_gran_idea_email', true );
			$arguments_email = get_post_meta( $email->ID, '_arguments_email', true );
			$content_boxes = get_post_meta( $email->ID, '_content_boxes', true );
			$engagement_boxes = get_post_meta( $email->ID, '_engagement_boxes', true );
			$ingredients = get_post_meta( $email->ID, '_ingredients', true );

			$soliloquios = get_post_meta( $email->ID, '_soliloquios_email', true );
			$gran_ideas_pitch = get_post_meta( $email->ID, '_gran_idea_pitch', true );
			$arguments_pitch = get_post_meta( $email->ID, '_arguments_pitch', true );
			$call_to_action = get_post_meta( $email->ID, '_call_to_action', true );

			$examples = get_post_meta( $email->ID, '_examples_email', true );

			foreach ($gran_ideas_email as $index => $value) {
				$metadata_array['gran_ideas_email'][$index] = get_post($value);
			}

			foreach ($arguments_email as $index => $value) {
				$metadata_array['arguments_email'][$index] = get_post($value);
			}

			foreach ($content_boxes as $index => $value) {
				$metadata_array['content_boxes'][$index] = get_post($value);
			}

			foreach ($engagement_boxes as $index => $value) {
				$metadata_array['engagement_boxes'][$index] = get_post($value);
			}

			foreach ($ingredients as $index => $value) {
				$metadata_array['ingredients'][$index] = get_post($value);
			}
			
			foreach ($soliloquios as $index => $value) {
				$metadata_array['soliloquios'][$index] = get_post($value);
			}

			foreach ($gran_ideas_pitch as $index => $value) {
				$metadata_array['gran_ideas_pitch'][$index] = get_post($value);
			}

			foreach ($arguments_pitch as $index => $value) {
				$metadata_array['arguments_pitch'][$index] = get_post($value);
			}

			foreach ($call_to_action as $index => $value) {
				$metadata_array['call_to_action'][$index] = get_post($value);
			}

			foreach ($examples as $index => $value) {
				$post = get_post($value);
				$metadata_array['examples_email'][$index] = get_post($value);
				$metadata_array['examples_email'][$index]->content = apply_filters( 'the_content', $post->post_content );
			}

			if($metadata_array['interlocutor']->ID == intval($interlocutor_id) && $metadata_array['situation']->ID == intval($situation_id) && $metadata_array['tono']->ID == intval($tono_id)) 
			{
				$data['email'] = $email;
				$data['metadata'] = $metadata_array;
			}	

		}

		echo json_encode($data);
	}

}