<?php 

/**
 * Interlocutors CPT Metabox
 *
 *
 * @link       https://lin3s.com
 * @since      1.0.0
 *
 * @package    Alexandria_Mail_Builder
 * @subpackage Alexandria_Mail_Builder/admin/models
 */

/*
* Creating a function to create our CPT
*/

class Alexandria_Mail_Interlocutors_Email_Metaboxes {

	/**
	 * The ID of this plugin.
	 *
	 * @since 		1.0.0
	 * @access 		private
	 * @var 		string 			$plugin_name 		The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since 		1.0.0
	 * @access 		private
	 * @var 		string 			$version 			The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since 		1.0.0
	 * @param 		string 			$plugin_name 			The name of this plugin.
	 * @param 		string 			$version 				The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	function alexandria_email_interlocutors_meta_box( $post ){

		$custom = get_post_custom( $post->ID );
		$order = (isset($custom["order"][0])) ? $custom["order"][0] : '0';

		wp_nonce_field( 'alexandria_interlocutors_email_meta_box', 'alexandria_interlocutors_email_meta_box_nonce' );

		?>

		<div class="pagebox">
			<label for="order"><?php _e('Order del Interlocutor', 'alexandria-mail-builder'); ?></label>
			<input type="text" name="order" value="<?php echo $order; ?>" />
			<p class="description"><?php _e('La gestión del ordern se hace automática, cambiar solo si se esta seguro.', 'alexandria-mail-builder'); ?></p>
		</div>

		<?php
	}

	function alexandria_interlocutors_email_save_meta_boxes( $post_id ){

		if( 'interlocutors_email' != get_post_type( $post_id )){
			return false;
		}

		if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
			return;
		}
		
		if( !current_user_can( 'edit_pages' ) ) {
			return;
		}

		if ( !isset( $_POST['order'] ) || !wp_verify_nonce( $_POST['alexandria_interlocutors_email_meta_box_nonce'], 'alexandria_interlocutors_email_meta_box' ) ) {
			return;
		}

		$order = $_POST["order"];

		if($order == 0) {

			$count_interlocutors = wp_count_posts('interlocutors_emails')->publish;

			if($count_interlocutors == 0) {
				update_post_meta($post_id, "order", 1);
			} else {
				update_post_meta($post_id, "order", $count_interlocutors);
			}

		} else {

			update_post_meta($post_id, "order", $order);
			
		}

	}

	function reorder_interlocutors_email_on_delete( $post_id ) {

		if( 'interlocutors_email' != get_post_type( $post_id )){
			return false;
		}

		$interlocutors = get_posts( array(
			'post_type' => 'interlocutors_email',
			'numberposts' => -1,
			'orderby' => 'order',
			'order' => 'ASC',
			'post__not_in' => array( $post_id )
		));

		foreach ($interlocutors as $key => $interlocutor) {
			update_post_meta($interlocutor->ID, "order", $key + 1);
		}

	}

	function reorder_interlocutors_email_on_send_trash( $post_id ) {

		if( 'interlocutors_email' != get_post_type( $post_id )){
			return false;
		}

		$interlocutors = get_posts( array(
			'post_type' => 'interlocutors_email',
			'numberposts' => -1,
			'orderby' => 'order',
			'order' => 'ASC',
			'post__not_in' => array( $post_id )
		));

		foreach ($interlocutors as $key => $interlocutor) {
			update_post_meta($interlocutor->ID, "order", $key + 1);
		}

	}
	

	// Add the custom columns to the interlocutors post type:
	function set_custom_edit_interlocutors_email_columns($columns) {
		unset( $columns['date'] );
		$columns['order'] = __( 'Orden', 'alexandria-email-builder' );
		$columns['date'] = __( 'Date' );
		return $columns;
	}

	// Add the data to the custom columns for the interlocutors post type:
	function custom_interlocutors_email_column( $column, $post_id ) {

		switch ( $column ) {

			case 'order' :
			echo $order = get_post_meta( $post_id, 'order', true );
			break;
			case 'date' :
			echo $date = get_post_meta( $post_id, 'date', true );
			break;

		}
	}

	/**
	 * Adds "Order" button on module list page
	 */
	function add_order_button_on_interlocutors_email_list_page()
	{
		global $current_screen;

	    // Not our post type, exit earlier
	    // You can remove this if condition if you don't have any specific post type to restrict to. 
		if ('interlocutors_email' != $current_screen->post_type) {
			return;
		}

		?>
		<script type="text/javascript">
			jQuery(document).ready( function($)
			{
				jQuery(".alignleft.actions.bulkactions").append("<a href='#' class='alexandria_email_order_button button action'>Ordernar</a>");
			});
		</script>
		<?php
	}

	function order_column_register_sortable($columns){
		$columns['order'] = 'order';
		return $columns;
	}

	function set_custom_interlocutors_email_admin_order($wp_query) {

		if (is_admin()) {

			$post_type = $wp_query->query['post_type'];

			if ($post_type == 'interlocutors_email') {

				$wp_query->set('order', 'ASC');
				$wp_query->set('meta_key', 'order');
				$wp_query->set('orderby', 'meta_value_num');
				
			}

		}

	}

}