<?php
/**
 * Globally-accessible functions
 *
 * @link 		https://lin3s.com
 * @since 		1.0.0
 *
 * @package		Alexandria_Mail_Builder
 * @subpackage 	Alexandria_Mail_Builder/includes
 */

/**
 * Get URL where is shortcode
 */
function alexandria_mail_builder_get_url_shortcode() {
	global $wpdb;

	$sql =  $wpdb->get_results("SELECT ID FROM {$wpdb->posts} WHERE post_content LIKE '%[alexandria-conversastion-builder]%' AND post_title!='' AND post_status='publish'");
	$post_id = $wpdb->get_var($sql);

	$url = get_permalink($post_id);

	return $url;
}

/**
 * Parse time format 00:00:00 to h m s
 */
function alexandria_mail_builder_parse_time($time) {

	preg_match("/([0-9]{1,2}):([0-9]{1,2})/", $time, $result);
	$hour = intval($result[1]);
	$min = intval($result[2]);

	$string = '';

	if($hour != '0') {
		$string = $hour.__('h','alexandria-mail-builder');
	}

	if($min != '0') {

		if($hour == '0') {
			$string = $string.$min.__('m','alexandria-mail-builder');
		}else {
			$string = $string.$min.__('m','alexandria-mail-builder');
		}
	}

	return $string;
}

/**
 * safe redirect
 */
function alexandria_mail_builder_redirect($url) {
	echo "<meta http-equiv='refresh' content='0;url=$url' />"; 
	exit;
}

function alexandria_mail_builder_strip_tags($content) {
	if(!current_user_can('unfiltered_html')) {
		$content = strip_tags($content, '<b><i><em><u><a><p><br><div><span><hr><font><img><strong>');
	}
	
	return $content;
}

/**
 * makes sure all values in array are ints. Typically used to sanitize POST data from multiple checkboxes
 */
function alexandria_mail_builder_int_array($value) {

	if(empty($value) or !is_array($value)) return array();
	
	$value = array_filter($value, 'is_numeric');

	return $value;
}

/**
 * function to eventually encrypt user's IP address if GDPR features are enabled
 */
function alexandria_mail_builder_user_ip() {
	if(get_option('alexandria_mail_builder_gdpr_ips') == 1) {
		$part1 = substr($_SERVER['REMOTE_ADDR'], 0, 8);
		$part2 = substr($_SERVER['REMOTE_ADDR'], 8, strlen($_SERVER['REMOTE_ADDR']));
		$part2 = md5($part2);
		return $part1.$part2;
	}
	
	// no GDPR features
	return $_SERVER['REMOTE_ADDR'];
}

/**
 * Returns the result of the get_max global function
 */
function alexandria_mail_builder_get_max( $array ) {

	return Alexandria_Mail_Builder_Globals::get_max( $array );

}

/**
 * Returns the result of the get_svg global function
 */
function alexandria_mail_builder_get_svg( $svg ) {

	return Alexandria_Mail_Builder_Globals::get_svg( $svg );

}

/**
 * Returns the result of the get_template global function
 */
function alexandria_mail_builder_get_template( $name ) {

	return Alexandria_Mail_Builder_Globals::get_template( $name );

}

class Alexandria_Mail_Builder_Globals {

	/**
	 * Returns the count of the largest arrays
	 *
	 * @param 		array 		$array 		An array of arrays to count
	 * @return 		int 					The count of the largest array
	 */
	public static function get_max( $array ) {

		if ( empty( $array ) ) { return '$array is empty!'; }

		$count = array();

		foreach ( $array as $name => $field ) {

			$count[$name] = count( $field );

		} //

		$count = max( $count );

		return $count;

 	} // get_max()

 	/**
 	 * Returns the requested SVG.
 	 *
 	 * @param 		string 		$svg 		The name of an SVG
 	 * @return 		mixed 					The SVG code
 	 */
 	public static function get_svg( $svg ) {

 		$return = '';

 		switch ( $svg ) {

 			case 'drag': $return = '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 20 20" class="drag" height="20px" width="20px"><path d="M19.7 10.5l-2.8 2.8c-.1.1-.3.2-.5.2-.4 0-.7-.3-.7-.7v-1.4h-4.3v4.3h1.4c.4 0 .7.3.7.7 0 .2-.1.4-.2.5l-2.8 2.8c-.1.1-.3.2-.5.2s-.4-.1-.5-.2l-2.8-2.8c-.1-.1-.2-.3-.2-.5 0-.4.3-.7.7-.7h1.4v-4.3H4.3v1.4c0 .4-.3.7-.7.7-.2 0-.4-.1-.5-.2L.3 10.5c-.1-.1-.2-.3-.2-.5s.1-.4.2-.5l2.8-2.8c.1-.1.3-.2.5-.2.4 0 .7.3.7.7v1.4h4.3V4.3H7.2c-.4 0-.7-.3-.7-.7 0-.2.1-.4.2-.5L9.5.3c.1-.1.3-.2.5-.2s.4.1.5.2l2.8 2.8c.1.1.2.3.2.5 0 .4-.3.7-.7.7h-1.4v4.3h4.3V7.2c0-.4.3-.7.7-.7.2 0 .4.1.5.2l2.8 2.8c.1.1.2.3.2.5s0 .4-.2.5z"/></svg>'; break;

		} // switch

		return $return;

 	} // get_svg()

 	/**
	 * Returns the path to a template file
	 *
	 * Looks for the file in these directories, in this order:
	 * 		Current theme
	 * 		Parent theme
	 * 		Current theme templates folder
	 * 		Parent theme templates folder
	 * 		This plugin
	 *
	 * To use a custom list template in a theme, copy the
	 * file from public/templates into a templates folder in your
	 * theme. Customize as needed, but keep the file name as-is. The
	 * plugin will automatically use your custom template file instead
	 * of the ones included in the plugin.
	 *
	 * @param 	string 		$name 			The name of a template file
	 * @return 	string 						The path to the template
	 */
 	public static function get_template( $name ) {

 		$template = '';

 		$locations[] = "{$name}.php";
 		$locations[] = "/templates/{$name}.php";

		/**
		 * Filter the locations to search for a template file
		 *
		 * @param 	array 		$locations 			File names and/or paths to check
		 */
		apply_filters( 'alexandria-mail-builder-template-paths', $locations );

		$template = locate_template( $locations, TRUE );

		if ( empty( $template ) ) {

			$template = plugin_dir_path( dirname( __FILE__ ) ) . 'public/templates/' . $name . '.php';

		}

		return $template;

 	} // get_template()

} // class
