<?php

/**
 * Mail Builder Landing Page template.
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/#single-post
 *
 * @package Alexandria_Mail_Builder
 * @subpackage Alexandria_Mail_Builder/public/templates
 */

if ( ! defined( 'ABSPATH' ) ) { exit; } // Exit if accessed directly

global $post;

$id = $post->ID;

$protected = SwpmProtection::get_instance();
if ($protected->is_protected($id)){

	$auth = SwpmAuth::get_instance();
	$permission = SwpmPermission::get_instance($auth->get('membership_level'));

	if(!SwpmMemberUtils::is_member_logged_in() || !$permission->is_permitted($id)) {
    //User is not logged-in. So don't go forward.
		return 0;
	}
}

$plugin_name = "alexandria-mail-builder";

$button_bg_color =  get_option( $plugin_name.'_button_bg_color' ) ?  get_option( $plugin_name.'_button_bg_color' ) : '#6628DD';
$button_text_color = get_option( $plugin_name.'_button_text_color' ) ?  get_option( $plugin_name.'_button_text_color' ) : '#FFFFFF';
$button_border_color = get_option( $plugin_name.'_button_border_color' ) ?  get_option( $plugin_name.'_button_border_color' ) : '#6628DD';

$button_bg_hover_color = get_option( $plugin_name.'_button_bg_hover_color' ) ?  get_option( $plugin_name.'_button_bg_hover_color' ) : '#FFFFFF';
$button_hover_text_color = get_option( $plugin_name.'_button_hover_text_color' ) ?  get_option( $plugin_name.'_button_hover_text_color' ) : '#6628DD';
$button_hover_border_color = get_option( $plugin_name.'_button_hover_border_color' ) ?  get_option( $plugin_name.'_button_hover_border_color' ) : '#6628DD';

$image_id = get_option( $plugin_name.'_header_background_image' ) ?  get_option( $plugin_name.'_header_background_image' ) : '';

$image_url = $image_id == '' ? ALEXANDRIA_MAIL_BUILDER_PUBLIC_URL.'assets/images/landing_header.jpg' : wp_get_attachment_url($image_id);

?>

<style>
	#site-header {
		display: none!important;
	}

	.entry-header {
		display: none!important;
	}

	#site-footer {
		display: none!important;
	}

	.alexandria-title-block::before {
		background-image: url('<?php echo $image_url; ?>');
	}

	#alexandria-title-overlay {
		background-color: #383838;
	}

	.alexandria-email-start-game-button {
		background-color: <?php echo $button_bg_color; ?>;
		border: 1px solid <?php echo $button_border_color; ?>;
		color: <?php echo $button_text_color; ?>;
	}

	.alexandria-email-start-game-button:hover {
		background-color: <?php echo $button_bg_hover_color ?>;
		border: 1px solid <?php echo $button_hover_border_color; ?>;
		color: <?php echo $button_hover_text_color; ?>;
	}
</style>

<div id="alexandria-main" class="alexandria-builder-container">

	<div class="alexandria-builder-wrapper">

		<div class="alexandria-title-wrapper">

			<div id="alexandria-title-block" class="alexandria-title-block">

				<div id="alexandria-title-overlay"></div>

				<div class="alexandria-builder-back-button-wrapper">

					<a href="/" id="alexandria-back-button" class="alexandria-builder-back-button" alt="<?php echo _e('Volver', 'alexandria-mail-builder'); ?>">

						<span class="alexandria-builder-back-button-arrow-icon">
							<img src="<?php echo ALEXANDRIA_MAIL_BUILDER_PUBLIC_URL.'assets/images/arrow-left.svg'; ?>" alt="<?php echo _e('Volver', 'alexandria-mail-builder'); ?>">
						</span>

						<span>
							<?php echo _e('Volver', 'alexandria-mail-builder'); ?>
						</span>	

					</a>

				</div>

				<div class="alexandria-builder-title">
					<h2>
						<?php echo get_option( $plugin_name.'_titulo_portada' ) ? get_option( $plugin_name.'_titulo_portada' ) : ''; ?>
					</h2>
				</div>

				<div class="alexandria-builder-intro-text">
					<p>
						<?php echo get_option( $plugin_name.'_subtitulo_portada' ) ? get_option( $plugin_name.'_subtitulo_portada' ) : ''; ?>
					</p>
				</div>

				<div class="alexandria-builder-duration">
					<span class="duration-icon">
						<img src="<?php echo ALEXANDRIA_MAIL_BUILDER_PUBLIC_URL.'assets/images/reloj.svg'?>" alt="Clock Icon" />
					</span>
					<span class="duration-text"><?php 

					$time = '';

					if ( get_option($plugin_name."_tiempo_portada") ) {
						$time = get_option( $plugin_name.'_tiempo_portada' );
						$time = alexandria_mail_builder_parse_time($time);
					}
					
					echo $time;

					?></span>
				</div>

				<div class="alexandria-builder-title-button">
					<button type="button" class="alexandria-email-start-game-button" data-url="<?php echo admin_url('admin-ajax.php')?>">
						<?php echo get_option( $plugin_name.'_button_text' ) != '' ? get_option( $plugin_name.'_button_text' ) : ''; ?>
					</button>
				</div>

			</div>

		</div>

		<div class="alexandria-builder__body-block">

			<div class="alexandria-builder__description">
				<span><?php _e('Descripción', 'alexandria-mail-builder' ); ?></span>
				<p>
					<?php echo get_option( $plugin_name.'_descripcion_portada' ) != '' ? get_option( $plugin_name.'_descripcion_portada' ) : ''; ?>
				</p>
			</div>

			<div class="alexandria-builder-start-button-wrapper">
				<button type="button" class="alexandria-email-start-game-button" data-url="<?php echo admin_url('admin-ajax.php')?>">
					<?php echo get_option( $plugin_name.'_button_text' ) != '' ? get_option( $plugin_name.'_button_text' ) : ''; ?>
				</button>
			</div>

			<!-- Objectives section -->
			<?php include 'elements/objectives-builder.php' ?>

			<div class="alexandria-builder-start-button-wrapper_bottom">
				
				<button type="button" class="alexandria-email-start-game-button" data-url="<?php echo admin_url('admin-ajax.php')?>">
					<?php echo get_option( $plugin_name.'_button_text' ) != '' ? get_option( $plugin_name.'_button_text' ) : ''; ?>
				</button>

			</div>

		</div>

	</div>

</div>

<!-- Loader section -->
<?php include 'elements/loading-spinner.php' ?>